###
### Characterization of the mating-type locus in historical and modern strains of Sclerotinia homoeocarpa and distribution of mating types in modern populations of the fungus
### Putman, A.I., L.P. Tredway, and I. Carbone
### Fungal Genetics and Biology
###
### Bash commands for in silico analyses
#!/bin/sh

##
## Generate repeat libraries using RepeatModeler v1.0.7
##
cd /usr/local/mat/rmod
sudo mkdir Bc0510
cd Bc0510
sudo /usr/local/mat/repeatmodeler/builddatabase -engine ncbi -name Bc0510 /usr/local/genome/botrytis_cinerea_1_supercontigs.fas
sudo sh -c 'nohup /usr/local/mat/repeatmodeler/repeatmodeler -database bc0510 >& Bc0510_1.out &'

cd /usr/local/mat/rmod
sudo mkdir Ss1980
cd Ss1980
sudo /usr/local/mat/repeatmodeler/builddatabase -engine ncbi -name Ss1980 /usr/local/genome/sclerotinia_sclerotiorum_2_supercontigs.fasta
sudo sh -c 'nohup /usr/local/mat/repeatmodeler/repeatmodeler -database ss1980 >& Ss1980_1.out &'

cd /usr/local/mat/rmod
sudo mkdir ShMB01
cd ShMB01
sudo /usr/local/mat/repeatmodeler/builddatabase -engine ncbi -name ShMB01 /usr/local/genome/s_homoeocarpa_final-scaffolds.fasta
sudo sh -c 'nohup /usr/local/mat/repeatmodeler/repeatmodeler -database Shmb01 >& ShMB01_1.out &'

# Repeats from three isolates concatenated with fungal RepBase library version 04/22/13


##
## Scan MAT locus sequences for repeats using library of repeats from RepBase and RepeatModeler runs
##
cd ~/desktop/aip_ncsu_docs/aip_mating/_analysis/2_repeatmasker

mkdir Run2_FBcSsSh
cd Run2_FBcSsSh
/usr/local/mat/repeatmasker/repeatmasker -pa 2 -s -dir . -xsmall -x -gff -excln -lib /usr/local/mat/repeatmasker/libraries/Putman_MAT-Sh_FGB_repeatmask-library.fa.class /Users/ImageCapture2576/Desktop/AIP_NCSU_docs/AIP_Mating/_analysis/0_seq_fin/comb/MAT_loci_fin.fas >& Run2_BBcSsSh.out
cd ..


##
## Mask genomic sequence using library of repeats from RepBase and RepeatModeler runs
##
mkdir run1_B_FBSS
cd run1_B_FBSS
/usr/local/bin/time -o /usr/local/mat/rmask/forGM/all_time.out -a -f "Elapsed:%E, User:%U, System:%S, Load:%P, MemMax:%M, MemAv:%t, MemTotAv:%K" /usr/local/mat/repeatmasker/repeatmasker -pa 4 -s -dir . -x -gff -excln -lib /usr/local/mat/repeatmasker/libraries/Putman_MAT-Sh_FGB_repeatmask-library.fa.class /usr/local/genome/botrytis_cinerea_1_supercontigs.fasta >& Run1_B_FBSS.out
echo "Run 1 (Bc/FBSS) complete." >> /usr/local/mat/rmask/forGM/all_time.out
cd ..

mkdir run2_Ss_FBSS
cd run2_Ss_FBSS
/usr/local/bin/time -o /usr/local/mat/rmask/forGM/all_time.out -a -f "Elapsed:%E, User:%U, System:%S, Load:%P, MemMax:%M, MemAv:%t, MemTotAv:%K" /usr/local/mat/repeatmasker/repeatmasker -pa 4 -s -dir . -x -gff -excln -lib /usr/local/mat/repeatmasker/libraries/Putman_MAT-Sh_FGB_repeatmask-library.fa.class /usr/local/genome/sclerotinia_sclerotiorum_2_supercontigs.fasta >& Run2_Ss_FBSS.out
echo "Run 2 (Ss/FBSS) complete." >> /usr/local/mat/rmask/forGM/all_time.out
cd ..


##
## Develop gene models from masked genomic sequence using GeneMark-ES v2.3c beta
##
mkdir Bc0510_FBSS
cd Bc0510_FBSS
time ~/gmes/gm_es.pl ~/fas/Bc0510_FBSS_mask.fas >& Bc0510_FBSS.out
echo "Bc0510_FBSS complete."
cd ..

mkdir Ss1980_FBSS
cd Ss1980_FBSS
time ~/gmes/gm_es.pl ~/fas/Ss1980_FBSS_mask.fas >& Ss1980_FBSS.out
echo "Ss1980_FBSS complete."
cd ..

##
## Use ES models to predict genes in MAT locus sequences using GeneMark.hmm v3.3
##
declare -a sp=(Bc0510 Ss1980)
declare -a rep=(FBSS)
declare -a iso=(608.1_AP-Mx_fin 6081_M115-SLA2_fin 14846_AP-Mx_fin 14846_M115-SLA2_fin 10942_fin 10943_fin 10944_fin 167641_fin 18472_fin 18473_fin CPB17_fin LEF17TF9_fin MB01_fin LFDF8_f TEK15T20_f)
declare -a form=(lst gff3 gtf)

for l in ${form[@]}; do
	mkdir ${l}
	cd ${l}
	cp /home/ec2-user/.gm_key /home/ec2-user/gm_run/${l}
	chmod 777 .gm_key
	for k in ${iso[@]}; do
		for i in ${sp[@]}; do
			for j in  ${rep[@]}; do
				time /home/ec2-user/gm/gmhmme3 /home/ec2-user/fas/${k}.fa -p -f ${l} -m /home/ec2-user/mod/${i}_${j}.mod -o ${k}_${i}_${j}_MAT-ann.${l} >& ${k}_${i}_${j}.out
				echo "${l} ${k} ${i} ${j} complete"
			done
			echo "${l} ${k} ${i} complete"
		done
		echo "${l} ${k} complete"
	done
	echo "${l} complete"
	cd ..
done

echo "Done."